/*
 * movedb.h -- move unwanted files to trash; This file is part of the
 * program 'move'
 * Copyright (C) 2005 2006 2007 2008 Prasad J Pandit
 *
 * 'move' is a free software; you can redistribute it and/or modify it under
 * the terms of GNU General Public Licence as published by Free Software
 * Foundation; either version 2 of the licence, or (at your option) any later
 * version.
 *
 * 'move' is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY of FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public Licence for more
 * details.
 *
 * You should have received a copy of the GNU General Public Licence along
 * with 'move'; if not, write to Free Software Foundation, Inc., 51 Franklin
 * St, Fifth Floor, Boston, MA 02110-1301 USA
 */
#ifndef MOVEDB_H
#define MOVEDB_H

#include <move.h>

typedef struct node
{
    char *path;
    struct node *next;
} node;

typedef struct
{
    node *head;
    node *tail;
} movedb;

/* create and return a new node to insert it into movedb */
extern node * get_node (const char *);

/* insert a new node into movedb returns +1 on success and -1 on error */
extern int m_insert (const char *);

/* delete node from movedb, containing string supplied as an argument */
extern void m_delete (const char *);

/* modify node with path supplied as argument */
extern void m_modify (node *, const char *);

/* search a node matching the basename string of the supplied path and returns
 * a copy of the path string */
extern char * m_search (const char *);

/* search a node matching the basename string of the supplied path and returns
 * the node to calling function */
extern node * m_search_node (const char *);

/* display movedb */
extern void m_display (void);

/* initialize and build movedb */
extern void m_read (void);

/* write movedb to file pointed to by mdb */
extern int m_write (void);

#endif
